Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(852)

Unified Diff: Source/core/html/forms/InputType.h

Issue 1115353002: Update renderer to layoutObject in core/html. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/forms/ImageInputType.cpp ('k') | Source/core/html/forms/InputType.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/forms/InputType.h
diff --git a/Source/core/html/forms/InputType.h b/Source/core/html/forms/InputType.h
index 884337ed0363adcb7ec577b1f9722558229e4021..8c1540af1c3b7520261e664db7b7c0711cff09d7 100644
--- a/Source/core/html/forms/InputType.h
+++ b/Source/core/html/forms/InputType.h
@@ -123,7 +123,7 @@ public:
virtual bool getAllowedValueStep(Decimal*) const;
virtual StepRange createStepRange(AnyStepHandling) const;
virtual void stepUp(int, ExceptionState&);
- virtual void stepUpFromRenderer(int);
+ virtual void stepUpFromLayoutObject(int);
virtual String badInputText() const;
virtual String rangeOverflowText(const Decimal& maximum) const;
virtual String rangeUnderflowText(const Decimal& minimum) const;
@@ -156,7 +156,7 @@ public:
// Should return true if the given DragData has more than one dropped files.
virtual bool receiveDroppedFiles(const DragData*);
virtual String droppedFileSystemId();
// Should return true if the corresponding renderer for a type can display a suggested value.
virtual bool canSetSuggestedValue();
virtual bool shouldSendChangeEventAfterCheckedChanged();
virtual bool canSetValue(const String&);
@@ -156,7 +156,7 @@ public:
virtual bool receiveDroppedFiles(const DragData*);
virtual String droppedFileSystemId();
- // Should return true if the corresponding renderer for a type can display a suggested value.
+ // Should return true if the corresponding layoutObject for a type can display a suggested value.
virtual bool canSetSuggestedValue();
virtual bool shouldSendChangeEventAfterCheckedChanged();
« no previous file with comments | « Source/core/html/forms/ImageInputType.cpp ('k') | Source/core/html/forms/InputType.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698